netapp_ontap.models.mediator_ping API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.mediator_ping`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

You can use this API to ping the BlueXP cloud service. The POST operation retrieves the details about service reachability, configurability, and ping latency.

## Performing a ping operation

You can perform a ping operation by issuing a POST request on /cluster/mediator-ping. Parameters are provided in the body of the POST request. There is only one required parameter.

### Required configuration fields

These fields are always required for any POST /cluster/mediator-ping request.

- `type` - Specifies the type of the mediator.

## Examples

POST request body for a ping to the BlueXP cloud service.

    # API
    /api/cluster/mediator-ping

### POST request body from a file

    ping_post_body.txt:
    {
      "type": "cloud"
    }
    curl -X POST https://<mgmt-ip>/api/cluster/mediator-ping -d "@ping_post_body.txt"

### Inline POST request body

    curl -X POST https://<mgmt-ip>/api/cluster/mediator-ping -d '{"type":"cloud"}'

### POST request response

    HTTP/1.1 200 OK
    Cache-Control: no-cache,no-store,must-revalidate
    Connection: close
    Date: Mon, 03 Mar 2025 16:40:20 GMT
    Server: libzapid-httpd
    Vary: Accept-Encoding,Origin
    Content-Length: 69
    Content-Type: application/hal+json
    Client-Date: Mon, 03 Mar 2025 16:40:20 GMT
    Client-Peer: 10.235.144.44:80
    Client-Response-Num: 1
    Content-Security-Policy: default-src 'self'; script-src 'self' 'unsafe-inline'; style-src 'self' 'unsafe-inline'; img-src 'self' data:; frame-ancestors: 'self'
    X-Content-Type-Options: nosniff
    {
      "reachable": true,
      "latency_ms": 50,
      "configurable": true,
      "high_latency": false,
      "proxy_configured": true,
      "proxy_used": true,
      "timeout_occurred": false
    }

## Classes

`class MediatorPingSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MediatorPing object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `configurable: bool GET`

    Indicates if the BlueXP cloud mediator is configurable. This depends on whether the ping latency is within a threshold.

    Example: true

  `high_latency: bool GET`

    Indicates if the ping latency of the BlueXP cloud server is greater than a threshold.

    Example: false

  `latency_ms: Size GET`

    Ping latency in milliseconds.

    Example: 150

  `proxy_configured: bool GET`

    Indicates if the HTTP proxy is configured on the cluster for the REST API calls to the BlueXP cloud server.

    Example: true

  `proxy_used: bool GET`

    Indicates if the HTTP proxy is used for the ping to the BlueXP cloud server.

    Example: true

  `reachable: bool GET`

    Ping status of the BlueXP cloud service.

    Example: true

  `timeout_occurred: bool GET`

    Indicates if the ping to the BlueXP cloud server failed due to a timeout.

    Example: false

  `type: str GET POST`

    Mediator type.

    Valid choices:

    - cloud
    - on_prem